pub struct AtomicComponentStoreRefMut<'a, T>where
T: TypedEcsData,{ /* private fields */ }Expand description
A mutable borrow of AtomicComponentStore.
Implementations
Sourceimpl<'a, T> AtomicComponentStoreRefMut<'a, T>where
T: TypedEcsData,
impl<'a, T> AtomicComponentStoreRefMut<'a, T>where
T: TypedEcsData,
Sourcepub fn insert(&mut self, entity: Entity, component: T) -> Option<T>
pub fn insert(&mut self, entity: Entity, component: T) -> Option<T>
Inserts a component for the given Entity index.
Returns the previous component, if any.
Sourcepub fn get(&self, entity: Entity) -> Option<&T>
pub fn get(&self, entity: Entity) -> Option<&T>
Gets an immutable reference to the component of Entity.
Sourcepub fn get_mut(&mut self, entity: Entity) -> Option<&mut T>
pub fn get_mut(&mut self, entity: Entity) -> Option<&mut T>
Gets a mutable reference to the component of Entity.
Sourcepub fn get_many_mut<const N: usize>(
&mut self,
entities: [Entity; N],
) -> [Option<&mut T>; N]
pub fn get_many_mut<const N: usize>( &mut self, entities: [Entity; N], ) -> [Option<&mut T>; N]
Get mutable pointers to the component data for multiple entities at the same time.
Panics
This will panic if the same entity is specified multiple times. This is invalid because it would mean you would have two mutable references to the same component data at the same time.
Sourcepub fn remove(&mut self, entity: Entity) -> Option<T>
pub fn remove(&mut self, entity: Entity) -> Option<T>
Removes the component of Entity.
Returns the component that was on the entity, if any.
Sourcepub fn iter(&self) -> impl Iterator<Item = &T>
pub fn iter(&self) -> impl Iterator<Item = &T>
Iterates immutably over all components of this type.
Very fast but doesn’t allow joining with other component types.
Sourcepub fn iter_mut(&mut self) -> impl Iterator<Item = &mut T>
pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut T>
Iterates mutably over all components of this type.
Very fast but doesn’t allow joining with other component types.
Sourcepub fn iter_with_bitset(
&self,
bitset: Rc<BitSetVec>,
) -> ComponentBitsetIterator<'_, T> ⓘ
pub fn iter_with_bitset( &self, bitset: Rc<BitSetVec>, ) -> ComponentBitsetIterator<'_, T> ⓘ
Iterates immutably over the components of this type where bitset indicates the indices of
entities.
Slower than iter() but allows joining between multiple component types.
Sourcepub fn iter_mut_with_bitset(
&mut self,
bitset: Rc<BitSetVec>,
) -> ComponentBitsetIteratorMut<'_, T> ⓘ
pub fn iter_mut_with_bitset( &mut self, bitset: Rc<BitSetVec>, ) -> ComponentBitsetIteratorMut<'_, T> ⓘ
Iterates mutable over the components of this type where bitset indicates the indices of
entities.
Slower than iter() but allows joining between multiple component types.